@@ -1,3 +1,3 @@
 #  Copyright (c) 2020 | KingKevin23 (@kingkevin023)
 
-from agspiel.utils import main
\ No newline at end of file
+from .main import *
\ No newline at end of file
